@@ -1,19 +1,18 @@
 package Yukki::Web;
 BEGIN {
-  $Yukki::Web::VERSION = '0.111160';
+  $Yukki::Web::VERSION = '0.111280';
 }
 use Moose;
 
 extends qw( Yukki );
 
-use Yukki::Error;
+use Yukki::Error qw( http_throw http_exception );
 use Yukki::Types qw( PluginList );
 use Yukki::Web::Context;
 use Yukki::Web::Router;
 use Yukki::Web::Settings;
 
 use CHI;
-use HTTP::Throwable::Factory qw( http_throw http_exception );
 use LWP::MediaTypes qw( add_type );
 use Plack::Session::Store::Cache;
 use Scalar::Util qw( blessed );
@@ -117,21 +116,25 @@ sub dispatch {
     try {
         my $match = $self->router->match($ctx->request->path);
 
-        http_throw('NotFound') unless $match;
+        http_throw('No action found matching that URL.', { 
+            status => 'NotFound',
+        }) unless $match;
 
         $ctx->request->path_parameters($match->mapping);
 
         my $access_level_needed = $match->access_level;
-        http_throw('Forbidden') unless $self->check_access(
-            user       => $ctx->session->{user},
-            repository => $match->mapping->{repository} // '-',
-            needs      => $access_level_needed,
-        );
+        http_throw('You are not authorized to run this action.', {
+            status => 'Forbidden',
+        }) unless $self->check_access(
+                user       => $ctx->session->{user},
+                repository => $match->mapping->{repository} // '-',
+                needs      => $access_level_needed,
+            );
 
         if ($ctx->session->{user}) {
             $ctx->response->add_navigation_item({
                 label => 'Sign out',
-                href  => '/logout',
+                href  => 'logout',
                 sort  => 100,
             });
         }
@@ -139,7 +142,7 @@ sub dispatch {
         else {
             $ctx->response->add_navigation_item({
                 label => 'Sign in',
-                href  => '/login',
+                href  => 'login',
                 sort  => 100,
             });
         }
@@ -150,7 +153,7 @@ sub dispatch {
             my $name = $config->name;
             $ctx->response->add_navigation_item({
                 label => $name,
-                href  => join('/', '/page/view',  $repository),
+                href  => join('/', 'page/view',  $repository),
                 sort  => 90,
             });
         }
@@ -162,13 +165,15 @@ sub dispatch {
     }
 
     catch {
+
         if (blessed $_ and $_->isa('Moose::Object') and $_->does('HTTP::Throwable')) {
 
             if ($_->does('HTTP::Throwable::Role::Status::Forbidden') 
                     and not $ctx->session->{user}) {
 
-                $response = http_exception(Found => {
-                    location => '/login',
+                $response = http_exception('Please login first.', {
+                    status   => 'Found',
+                    location => ''.$ctx->rebase_url('login'),
                 })->as_psgi($env);
             }
 
@@ -180,7 +185,8 @@ sub dispatch {
         else {
             warn "ISE: $_";
 
-            $response = http_exception('InternalServerError', {
+            $response = http_exception($_, {
+                status           => 'InternalServerError', 
                 show_stack_trace => 0,
             })->as_psgi($env);
         }
@@ -230,7 +236,7 @@ Yukki::Web - the Yukki web server
 
 =head1 VERSION
 
-version 0.111160
+version 0.111280
 
 =head1 DESCRIPTION
 
