@@ -1,11 +1,11 @@
 package Yukki::Web::Controller::Redirect;
 BEGIN {
-  $Yukki::Web::Controller::Redirect::VERSION = '0.111160';
+  $Yukki::Web::Controller::Redirect::VERSION = '0.111280';
 }
 use 5.12.1;
 use Moose;
 
-use HTTP::Throwable::Factory qw( http_throw );
+use Yukki::Error qw( http_throw );
 
 # ABSTRACT: Simple controller for handling internal redirects
 
@@ -16,8 +16,11 @@ sub fire {
     my $redirect = $ctx->request->path_parameters->{redirect};
 
     Yukki::Error->throw("no redirect URL named") unless $redirect;
-
-    http_throw('MovedPermanently', { location => $redirect });
+ 
+    http_throw("Go to $redirect.", {
+        status   => 'MovedPermanently', 
+        location => $redirect,
+    });
 }
 
 1;
@@ -31,7 +34,7 @@ Yukki::Web::Controller::Redirect - Simple controller for handling internal redir
 
 =head1 VERSION
 
-version 0.111160
+version 0.111280
 
 =head1 DESCRIPTION
 
